=======
Credits
=======

Development Lead
----------------

* Sven Grunewaldt <strayer@olle-orks.org>

Contributors
------------

* Titusz Pan <tp@craft.de>
* George Pchelkin <george@pchelk.in>
* Shinya Okano <tokibito@gmail.com>
